package net.nourdine.jp.main;

import java.text.MessageFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;
import net.nourdine.jp.dialog.UIDialog;
import net.nourdine.jp.build.JsProject;
import net.nourdine.jp.dependency.DependencyManager;
import net.nourdine.jp.log.JsPackerLogger;
import net.nourdine.jp.time.Timer;

public class JsPacker {

   public static String PREFIX = "--";
   public static String XML_CONFIG_PARAM = "config";
   public static String MINIFY_PARAM = "minify";
   public static String VERBOSE_PARAM = "verbose";
   public static JsPackerLogger log = JsPackerLogger.getInstance();
   public static Properties dialog = UIDialog.getInstace().getProperties();
   public static Timer timer = null;

   public static void main(String[] args) {
      timer = new Timer();
      boolean minify = true;
      boolean verbose = false;
      Map<String, String> arguments = getArgsMap(args);
      String xmlConfigFilePath = arguments.get(XML_CONFIG_PARAM);
      if ("false".equals(arguments.get(MINIFY_PARAM))) {
         minify = false;
      }
      if ("true".equals(arguments.get(VERBOSE_PARAM))) {
         verbose = true;
      }
      log.init(verbose);
      if (xmlConfigFilePath != null) {
         build(xmlConfigFilePath, minify, verbose);
      } else {
         log.error(dialog.getProperty("config_param_missing"));
      }
   }

   public static void build(String xmlConfigFilePath, boolean minify, boolean verbose) {
      log.info(dialog.getProperty("build_started"));
      JsProject project = new JsProject(xmlConfigFilePath, minify, verbose);
      project.buildStandalone();
      DependencyManager.flushDependencies();
      log.info(MessageFormat.format(dialog.getProperty("build_success"), timer.getElapsedTime()));
   }

   private static void addArgToMap(String[] CLIarguments, Map<String, String> argsMap, int argIndex, String argKey) {
      try {
         argsMap.put(argKey, CLIarguments[argIndex + 1]);
      } catch (ArrayIndexOutOfBoundsException e) {
         e.printStackTrace();
      }
   }

   private static Map<String, String> getArgsMap(String[] CLIarguments) {

      HashMap<String, String> argsMap = new HashMap<String, String>();

      for (int i = 0; i < CLIarguments.length; i++) {
         String arg = CLIarguments[i];
         if ((PREFIX + XML_CONFIG_PARAM).equals(arg)
                 || (PREFIX + MINIFY_PARAM).equals(arg)
                 || (PREFIX + VERBOSE_PARAM).equals(arg)) {
            addArgToMap(CLIarguments, argsMap, i, arg.substring(2));
         }
      }
      return argsMap;
   }
}
